@@ -36,8 +36,9 @@ class XPathContext(object):
     :param timezone: implicit timezone to be used when a date, time, or dateTime value does \
     not have a timezone.
     """
-    def __init__(self, root, item=None, position=0, size=1, axis=None, variables=None,
-                 current_dt=None, timezone=None):
+    def __init__(self, root, item=None, position=0, size=1, axis=None,
+                 variables=None, current_dt=None, timezone=None,
+                 documents=None, collections=None, default_collection=None):
         if not is_element_node(root) and not is_document_node(root):
             raise ElementPathTypeError(
                 "invalid argument root={!r}, an Element is required.".format(root)
@@ -55,6 +56,9 @@ class XPathContext(object):
         self.variables = {} if variables is None else dict(variables)
         self.current_dt = current_dt or datetime.datetime.now()
         self.timezone = timezone
+        self.documents = {} if documents is None else dict(documents)
+        self.collections = {} if collections is None else dict(collections)
+        self.default_collection = default_collection
         self._elem = item if is_element_node(item) else root
         self._parent_map = None
 
@@ -73,6 +77,9 @@ class XPathContext(object):
             variables=self.variables.copy(),
             current_dt=self.current_dt,
             timezone=self.timezone,
+            documents=self.documents.copy(),
+            collections=self.collections.copy(),
+            default_collection=self.default_collection,
         )
         obj._elem = self._elem
         obj._parent_map = self._parent_map
@@ -108,10 +115,13 @@ class XPathContext(object):
     def get_path(self, item):
         """Cached path resolver for elements and attributes. Returns absolute paths."""
         path = []
-        if isinstance(item, (AttributeNode, TypedAttribute)):
+        if isinstance(item, AttributeNode):
             path.append('@%s' % item[0])
             item = self._elem
-        if isinstance(item, TypedElement):
+        elif isinstance(item, TypedAttribute):
+            path.append('@%s' % item[0][0])
+            item = self._elem
+        elif isinstance(item, TypedElement):
             item = item[0]
 
         while True:
@@ -179,7 +189,7 @@ class XPathContext(object):
         self.item, self.size, self.position, self.axis = status
 
     def iter_preceding(self):
-        item = e = self.item[0] if isinstance(self.item, TypedElement) else self.item
+        item = self.item[0] if isinstance(self.item, TypedElement) else self.item
         if not is_etree_element(item):
             return
 
@@ -187,20 +197,21 @@ class XPathContext(object):
         self.axis = 'preceding'
 
         ancestors = []
+        elem = item
         while True:
-            parent = self.get_parent(e)
+            parent = self.get_parent(elem)
             if parent is None:
                 break
             else:
                 ancestors.append(parent)
-                e = parent
+                elem = parent
 
-        for e in self.root.iter():
-            if e is item:
+        for elem in self.root.iter():
+            if elem is item:
                 break
-            elif e not in ancestors:
-                self.item = e
-                yield e
+            elif elem not in ancestors:
+                self.item = elem
+                yield elem
 
         self.item, self.size, self.position, self.axis = status
 
@@ -271,28 +282,23 @@ class XPathContext(object):
 
         self.item, self.size, self.position, self.axis = status
 
-    def iter(self, axis=None):
-        status = self.item, self.size, self.position, self.axis
-        self.axis = axis
-
-        if self.item is None:
-            self.size, self.position = 1, 0
-            yield self.root
-            self.item = self.root.getroot() if is_document_node(self.root) else self.root
-        elif isinstance(self.item, TypedElement):
-            self.item = self.item[0]
-        elif not is_etree_element(self.item):
-            return
+    def iter(self):
+        """Iterates context nodes."""
+        status = self.item, self.size, self.position
+        self.item = self.root
+        if is_document_node(self.item):
+            yield self.item
+            self.item = self.item.getroot()
 
         for item in self._iter_context():
             yield item
 
-        self.item, self.size, self.position, self.axis = status
+        self.item, self.size, self.position, = status
 
     def iter_results(self, results):
         """Iterates results in document order."""
         status = self.item, self.size, self.position
-        self.item = self.root
+        self.item = self.root.getroot() if is_document_node(self.root) else self.root
 
         for item in self._iter_context():
             if item in results:
